@@ -6,7 +6,7 @@ package Test::OpenID::Server;
 use Net::OpenID::Server;
 use base qw/Test::HTTP::Server::Simple HTTP::Server::Simple::CGI/;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -90,7 +90,7 @@ sub _is_identity {
 sub _identity_url {
     my $self = shift;
     my $id   = shift;
-    return "http://localhost:@{[$self->port]}/$id";
+    return "http://$ENV{HTTP_HOST}/$id";
 }
 
 #=head2 modify_trust NAME, URL, BOOLEAN
@@ -122,8 +122,7 @@ sub handle_request {
         # We're dealing with the OpenID server endpoint
         
         my $nos = Net::OpenID::Server->new(
-            get_args      => $cgi,
-            post_args     => $cgi,
+            args          => $cgi,
             get_user      => \&_get_user,
             is_identity   => sub { $self->_is_identity( $_[1] ) },
             is_trusted    => sub { return 1 },
@@ -150,7 +149,7 @@ sub handle_request {
             print <<"            END";
 <html>
   <head>
-    <link rel="openid.server" href="$ENV{'SERVER_URL'}openid.server" />
+    <link rel="openid.server" href="http://$ENV{'HTTP_HOST'}/openid.server" />
   </head>
   <body>
     <p>OpenID identity page for $id.</p>
